/// <reference types="node" />
import { TaskLogger } from "../logger/TaskLogger";
import { ChildProcess } from "child_process";
import { PackageInfo } from "workspace-tools";
import { RunContext } from "../types/RunContext";
import { NpmClient } from "../types/ConfigOptions";
import { CacheOptions } from "../types/CacheOptions";
export declare type NpmScriptTaskStatus = "completed" | "failed" | "pending" | "started" | "skipped";
export interface NpmScriptTaskConfig {
    npmClient: NpmClient;
    reporter: string;
    cacheOptions: CacheOptions;
    cache: boolean;
    resetCache: boolean;
    continueOnError: boolean;
    safeExit: boolean;
    nodeArgs: string[];
    passThroughArgs: string[];
}
export declare class WrappedTask {
    task: string;
    private root;
    info: PackageInfo;
    private config;
    private context;
    static npmCmd: string;
    static activeProcesses: Set<ChildProcess>;
    static gracefulKillTimeout: number;
    npmArgs: string[];
    startTime: [number, number];
    duration: [number, number];
    status: NpmScriptTaskStatus;
    logger: TaskLogger;
    static killAllActiveProcesses(): void;
    constructor(task: string, root: string, info: PackageInfo, config: NpmScriptTaskConfig, context: RunContext);
    onStart(): void;
    onComplete(): void;
    onFail(): void;
    onSkipped(hash: string | null): void;
    getCache(): Promise<{
        hash: string | null;
        cacheHit: boolean;
    }>;
    saveCache(hash: string | null): Promise<void>;
    runScript(): Promise<unknown>;
    run(): Promise<boolean>;
}
